VolumeEntity mixin

Mixin applications

Properties

close ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
MA10Volume ↔ double?
getter/setter pair
MA5Volume ↔ double?
getter/setter pair
open ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vol ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited