renderer/base_chart_painter library

Classes

BaseChartPainter
Canvas
An interface for recording graphical operations.
Color
An immutable color value in ARGB format.
CustomPainter
The interface used by CustomPaint (in the widgets library) and RenderCustomPaint (in the rendering library).
Rect
An immutable, 2D, axis-aligned, floating-point rectangle whose coordinates are relative to a given origin.
Size
Holds a 2D floating-point size.
TextStyle
An immutable style describing how to format and paint text.

Constants

required → const Required
Annotation on named parameter that should always have an argument supplied.