BaseChartRenderer<T> class abstract

Implementers

Constructors

BaseChartRenderer({required Rect chartRect, required double maxValue, required double minValue, required double topPadding, required int fixedLength, required Color gridColor})

Properties

chartPaint ↔ Paint
getter/setter pair
chartRect ↔ Rect
getter/setter pair
fixedLength ↔ int
getter/setter pair
gridPaint ↔ Paint
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxValue ↔ double
getter/setter pair
minValue ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleY ↔ double
getter/setter pair
topPadding ↔ double
getter/setter pair

Methods

drawChart(T lastPoint, T curPoint, double lastX, double curX, Size size, Canvas canvas) → void
drawGrid(Canvas canvas, int gridRows, int gridColumns) → void
drawLine(double? lastPrice, double? curPrice, Canvas canvas, double lastX, double curX, Color color) → void
drawText(Canvas canvas, T data, double x) → void
drawVerticalText(dynamic canvas, dynamic textStyle, int gridRows) → void
format(double? n) → String
getTextStyle(Color color) → TextStyle
getY(double y) → double
getYFromPrice(double screenY) → double
根据屏幕Y坐标计算对应的价格
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited