VolRenderer class

Inheritance

Constructors

VolRenderer(Rect mainRect, double maxValue, double minValue, double topPadding, int fixedLength, ChartStyle chartStyle, ChartColors chartColors)

Properties

chartColors → ChartColors
final
chartPaint ↔ Paint
getter/setter pairinherited
chartRect ↔ Rect
getter/setter pairinherited
chartStyle → ChartStyle
final
fixedLength ↔ int
getter/setter pairinherited
gridPaint ↔ Paint
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
maxValue ↔ double
getter/setter pairinherited
minValue ↔ double
getter/setter pairinherited
mVolWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleY ↔ double
getter/setter pairinherited
topPadding ↔ double
getter/setter pairinherited

Methods

drawChart(VolumeEntity lastPoint, VolumeEntity curPoint, double lastX, double curX, Size size, Canvas canvas) → void
override
drawGrid(Canvas canvas, int gridRows, int gridColumns) → void
override
drawLine(double? lastPrice, double? curPrice, Canvas canvas, double lastX, double curX, Color color) → void
inherited
drawText(Canvas canvas, VolumeEntity data, double x) → void
override
drawVerticalText(dynamic canvas, dynamic textStyle, int gridRows) → void
override
format(double? n) → String
inherited
getTextStyle(Color color) → TextStyle
inherited
getVolY(double value) → double
getY(double y) → double
inherited
getYFromPrice(double screenY) → double
根据屏幕Y坐标计算对应的价格
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited